@@ -11,7 +11,7 @@ use URI;
 use URI::QueryParam;
 use URI::file;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 has dsn => sub { _dsn_from_path(shift->_tempfile_path) };
 has max_connections => 5;
@@ -90,8 +90,9 @@ sub _enqueue {
 
 sub _tempfile_path {
   my $self = shift;
-  $self->{tempfile} = File::Temp->new(EXLOCK => 0);
-  return URI::file->new($self->{tempfile}->filename)->path;
+  $self->{tempdir} //= File::Temp->newdir;
+  $self->{tempfile} = File::Temp->new(DIR => $self->{tempdir}, EXLOCK => 0);
+  return URI::file->new($self->{tempfile})->path;
 };
 
 sub _uri_from_path { URI->new->Mojo::Base::tap(scheme => 'file')->Mojo::Base::tap(path => shift) }
@@ -250,6 +251,21 @@ options.
 L<Mojo::SQLite> inherits all methods from L<Mojo::EventEmitter> and implements
 the following new ones.
 
+=head2 new
+
+  my $sql = Mojo::SQLite->new;
+  my $sql = Mojo::SQLite->new('file:test.db');
+
+Construct a new L<Mojo::SQLite> object and parse connection string with
+L</"from_string"> if necessary.
+
+  # Customize configuration further
+  my $sql = Mojo::SQLite->new->dsn('dbi:SQLite:dbname=test.db');
+  my $sql = Mojo::SQLite->new->dsn('dbi:SQLite:uri=file:test.db?mode=memory');
+
+  # Pass filename directly
+  my $sql = Mojo::SQLite->new->from_filename($filename);
+
 =head2 db
 
   my $db = $sql->db;
@@ -323,21 +339,6 @@ will be parsed and applied to L</"options">.
   $sql->from_string('data.db?PrintError=1&sqlite_allow_multiple_statements=1');
   $sql->from_string(URI::file->new($filename)->Mojo::Base::tap(query_form_hash => {PrintError => 1}));
 
-=head2 new
-
-  my $sql = Mojo::SQLite->new;
-  my $sql = Mojo::SQLite->new('file:test.db');
-
-Construct a new L<Mojo::SQLite> object and parse connection string with
-L</"from_string"> if necessary.
-
-  # Customize configuration further
-  my $sql = Mojo::SQLite->new->dsn('dbi:SQLite:dbname=test.db');
-  my $sql = Mojo::SQLite->new->dsn('dbi:SQLite:uri=file:test.db?mode=memory');
-
-  # Pass filename directly
-  my $sql = Mojo::SQLite->new->from_filename($filename);
-
 =head1 REFERENCE
 
 This is the class hierarchy of the L<Mojo::SQLite> distribution.
